﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace UserControlProgressBar
{
    public partial class CV_ProgressBar : UserControl
    {
        // Variabili interne.
        private int _Value = 0;
        private bool _ShowPercentage = true;
        private Color _BackColorBar = Color.Blue;
        private Color _ForeColorFont = Color.Black;
        private Font _FontOfPercentage = new Font("Verdana", 9);

        // Eventi.
        public event EventHandler ValueChanged;

        public CV_ProgressBar()
        {
            InitializeComponent();
        }

        private void CV_ProgressBar_Load(object sender, EventArgs e)
        {
            // Imposta il pnlContainer.
            pnlContainer.Dock = DockStyle.Fill;
            pnlContainer.BorderStyle = System.Windows.Forms.BorderStyle.Fixed3D;
            // Imposta il pnlProgressBar.
            pnlProgressBar.Parent = pnlContainer;   // Contenuto nel pnlContainer.
            pnlProgressBar.Top = 0;
            pnlProgressBar.Left = 0;
            pnlProgressBar.Height = pnlContainer.Height;
            pnlProgressBar.Width = pnlContainer.Width * _Value / 100;
            pnlProgressBar.BorderStyle = System.Windows.Forms.BorderStyle.None;
            pnlProgressBar.BringToFront();
        }

        #region Proprietà.
        // Valore della ProgressBar.
        public int Value
        {
            get { return _Value; }
            set
            {
                try
                {
                    if (value < 0)
                        value = 0;
                    if (value > 100)
                        value = 100;
                    if (_Value == value)
                        return;
                    // Si imposta la variabile interna.
                    _Value = value;
                    // Si disegna il pnlProgressBar con larghezza opportuna.
                    pnlProgressBar.Width = pnlContainer.Width * value / 100;
                    // Si forzano gli eventi Paint() dei Panel.
                    pnlContainer.Refresh();
                    pnlProgressBar.Refresh();
                    // Genera l'evento.
                    EventHandler handler = ValueChanged;
                    if (handler != null) 
                        handler(this, EventArgs.Empty); 
                }
                catch (Exception)
                {

                }
            }
        }

        // Bool per mostrare o no la stringa con la percentuale.
        public bool ShowPercentage
        {
            get { return _ShowPercentage; }
            set { _ShowPercentage = value; }
        }

        // BackColor del pannello interno.
        public Color BackColorBar
        {
            get { return _BackColorBar; }
            set 
            { 
                _BackColorBar = value;
                pnlProgressBar.BackColor = _BackColorBar;
            }
        }

        // Font del valore percentuale.
        public Font FontOfPercentage
        {
            get
            {
                return _FontOfPercentage;
            }
            set
            {
                _FontOfPercentage = value;
            }
        }

        // ForeColor del valore percentuale.
        public Color ForeColorFont
        {
            get { return _ForeColorFont; }
            set { _ForeColorFont = value; }
        }
        #endregion

        private void pnl_Paint(object sender, PaintEventArgs e)
        {
            if (!_ShowPercentage)
            {
                return;
            }
            try
            {
                // Crea la stringa.
                String drawString = _Value.ToString() + "%";

                // Crea font e brush.
                Font drawFont = _FontOfPercentage;
                SolidBrush drawBrush = new SolidBrush(_ForeColorFont);

                // Dimensione della stringa da mostrare.
                SizeF sizeString = new SizeF();
                using (Graphics g = Graphics.FromImage(new Bitmap(1, 1)))
                {
                    sizeString = g.MeasureString(drawString, drawFont);
                }

                // Crea il punto nell'angolo alto a sinistra.
                float left = (pnlContainer.Width - sizeString.Width) / 2;
                float top = (pnlContainer.Height - sizeString.Height) / 2;
                PointF drawPoint = new PointF(left, top);

                // Disegna la stringa.
                e.Graphics.DrawString(drawString, drawFont, drawBrush, drawPoint);
            }
            catch (Exception)
            {

            }
        }
    }
}
